Spectrum
========

Spectrum
--------

.. automodule:: unite.spectrum.spectrum
   :members:
   :undoc-members:
   :show-inheritance:

Spectra Collection
------------------

.. automodule:: unite.spectrum.collection
   :members:
   :show-inheritance:

Loaders
-------

.. automodule:: unite.spectrum.loaders
   :members:
   :undoc-members:
   :show-inheritance:
